[Libreoffice-commits] core.git: 2 commits - include/formula include/framework

Noel Grandin noel at peralex.com
Thu Oct 22 00:27:01 PDT 2015


 include/formula/FormulaCompiler.hxx               |   14 +++-----
 include/formula/FormulaOpCodeMapperObj.hxx        |   34 +++++++++----------
 include/formula/IFunctionDescription.hxx          |    8 ++--
 include/formula/grammar.hxx                       |   38 +++++++++++-----------
 include/framework/actiontriggerhelper.hxx         |    8 ++--
 include/framework/addonmenu.hxx                   |   16 ++++-----
 include/framework/addonsoptions.hxx               |   14 ++++----
 include/framework/bmkmenu.hxx                     |    4 --
 include/framework/configimporter.hxx              |    8 ++--
 include/framework/documentundoguard.hxx           |    4 +-
 include/framework/eventsconfiguration.hxx         |    4 +-
 include/framework/framelistanalyzer.hxx           |   18 +++++-----
 include/framework/imageproducer.hxx               |    4 +-
 include/framework/interaction.hxx                 |   18 +++++-----
 include/framework/menuconfiguration.hxx           |   17 +++++----
 include/framework/preventduplicateinteraction.hxx |    8 ++--
 include/framework/sfxhelperfunctions.hxx          |   24 ++++++-------
 include/framework/statusbarconfiguration.hxx      |   12 +++---
 include/framework/toolboxconfiguration.hxx        |   12 +++---
 include/framework/undomanagerhelper.hxx           |   20 +++++------
 20 files changed, 141 insertions(+), 144 deletions(-)

New commits:
commit 1b3f81bd584cfceb537f04f3a240bf505d19b7bf
Author: Noel Grandin <noel at peralex.com>
Date:   Tue Oct 20 17:26:13 2015 +0200

    com::sun::star->css in include/framework
    
    Change-Id: I60874ab8d3cc9adaea8757d6888e341accce2083
    Reviewed-on: https://gerrit.libreoffice.org/19494
    Tested-by: Jenkins <ci at libreoffice.org>
    Reviewed-by: Noel Grandin <noelgrandin at gmail.com>

diff --git a/include/framework/addonmenu.hxx b/include/framework/addonmenu.hxx
index b92d716..b909d61 100644
--- a/include/framework/addonmenu.hxx
+++ b/include/framework/addonmenu.hxx
@@ -37,11 +37,11 @@ namespace framework
 class FWE_DLLPUBLIC AddonMenu : public PopupMenu
 {
     public:
-        AddonMenu( const ::com::sun::star::uno::Reference< ::com::sun::star::frame::XFrame >& rFrame );
+        AddonMenu( const css::uno::Reference< css::frame::XFrame >& rFrame );
         virtual ~AddonMenu();
 
     protected:
-        ::com::sun::star::uno::Reference< ::com::sun::star::frame::XFrame > m_xFrame;
+        css::uno::Reference< css::frame::XFrame > m_xFrame;
 };
 
 class AddonMenuManager;
@@ -57,7 +57,7 @@ class FWE_DLLPUBLIC AddonPopupMenu : public AddonMenu
         void               SetCommandURL( const OUString& aCmdURL ) { m_aCommandURL = aCmdURL; }
 
     private:
-        AddonPopupMenu( const com::sun::star::uno::Reference< com::sun::star::frame::XFrame >& rFrame );
+        AddonPopupMenu( const css::uno::Reference< css::frame::XFrame >& rFrame );
 
         OUString               m_aCommandURL;
 
@@ -81,7 +81,7 @@ class FWE_DLLPUBLIC AddonMenuManager
         static bool IsCorrectContext(const OUString& rModuleIdentifier, const OUString& rContext);
 
         // Factory method to create different Add-On menu types
-        static PopupMenu* CreatePopupMenuType( MenuType eMenuType, const com::sun::star::uno::Reference< com::sun::star::frame::XFrame >& rFrame );
+        static PopupMenu* CreatePopupMenuType( MenuType eMenuType, const css::uno::Reference< css::frame::XFrame >& rFrame );
 
         // Create the Add-Ons menu
         static AddonMenu* CreateAddonMenu( const css::uno::Reference< css::frame::XFrame >& rFrame,
@@ -106,18 +106,18 @@ class FWE_DLLPUBLIC AddonMenuManager
                                      MenuType    nSubMenuType,
                                      sal_uInt16      nInsPos,
                                      sal_uInt16&     nUniqueMenuId,
-                                     const com::sun::star::uno::Sequence< com::sun::star::uno::Sequence< com::sun::star::beans::PropertyValue > >& aAddonMenuDefinition,
-                                     const com::sun::star::uno::Reference< com::sun::star::frame::XFrame >& rFrame,
+                                     const css::uno::Sequence< css::uno::Sequence< css::beans::PropertyValue > >& aAddonMenuDefinition,
+                                     const css::uno::Reference< css::frame::XFrame >& rFrame,
                                      const ::rtl::OUString& rModuleIdentifier );
 
         // Retrieve the menu entry property values from a sequence
-        static void       GetMenuEntry( const com::sun::star::uno::Sequence< com::sun::star::beans::PropertyValue >& rAddonMenuEntry,
+        static void       GetMenuEntry( const css::uno::Sequence< css::beans::PropertyValue >& rAddonMenuEntry,
                                         OUString& rTitle,
                                         OUString& rURL,
                                         OUString& rTarget,
                                         OUString& rImageId,
                                         OUString& rContext,
-                                        com::sun::star::uno::Sequence< com::sun::star::uno::Sequence< com::sun::star::beans::PropertyValue > >& rAddonSubMenu );
+                                        css::uno::Sequence< css::uno::Sequence< css::beans::PropertyValue > >& rAddonSubMenu );
 };
 
 } // namespace framework
diff --git a/include/framework/addonsoptions.hxx b/include/framework/addonsoptions.hxx
index 92bf904..8241f32 100644
--- a/include/framework/addonsoptions.hxx
+++ b/include/framework/addonsoptions.hxx
@@ -51,7 +51,7 @@ struct FWE_DLLPUBLIC MergeMenuInstruction
     OUString     aMergeCommandParameter;
     OUString     aMergeFallback;
     OUString     aMergeContext;
-    ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Sequence< ::com::sun::star::beans::PropertyValue > > aMergeMenu;
+    css::uno::Sequence< css::uno::Sequence< css::beans::PropertyValue > > aMergeMenu;
 };
 typedef ::std::vector< MergeMenuInstruction > MergeMenuInstructionContainer;
 
@@ -63,7 +63,7 @@ struct FWE_DLLPUBLIC MergeToolbarInstruction
     OUString     aMergeCommandParameter;
     OUString     aMergeFallback;
     OUString     aMergeContext;
-    ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Sequence< ::com::sun::star::beans::PropertyValue > > aMergeToolbarItems;
+    css::uno::Sequence< css::uno::Sequence< css::beans::PropertyValue > > aMergeToolbarItems;
 };
 
 typedef ::std::vector< MergeToolbarInstruction > MergeToolbarInstructionContainer;
@@ -75,7 +75,7 @@ struct FWE_DLLPUBLIC MergeStatusbarInstruction
     ::rtl::OUString     aMergeCommandParameter;
     ::rtl::OUString     aMergeFallback;
     ::rtl::OUString     aMergeContext;
-    ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Sequence< ::com::sun::star::beans::PropertyValue > > aMergeStatusbarItems;
+    css::uno::Sequence< css::uno::Sequence< css::beans::PropertyValue > > aMergeStatusbarItems;
 };
 
 typedef ::std::vector< MergeStatusbarInstruction > MergeStatusbarInstructionContainer;
@@ -140,7 +140,7 @@ class FWE_DLLPUBLIC AddonsOptions
             @onerror    We return an empty list.
         *//*-*****************************************************************************************************/
 
-        const ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Sequence< ::com::sun::star::beans::PropertyValue > >& GetAddonsMenu() const;
+        const css::uno::Sequence< css::uno::Sequence< css::beans::PropertyValue > >& GetAddonsMenu() const;
 
         /*-****************************************************************************************************
             @short      Gets the menu bar part of all addon components registered
@@ -149,7 +149,7 @@ class FWE_DLLPUBLIC AddonsOptions
             @onerror    We return sal_False
         *//*-*****************************************************************************************************/
 
-        const ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Sequence< ::com::sun::star::beans::PropertyValue > >& GetAddonsMenuBarPart() const;
+        const css::uno::Sequence< css::uno::Sequence< css::beans::PropertyValue > >& GetAddonsMenuBarPart() const;
 
         /*-****************************************************************************************************
             @short      Gets a toolbar part of an single addon
@@ -158,7 +158,7 @@ class FWE_DLLPUBLIC AddonsOptions
             @onerror    We return sal_False
         *//*-*****************************************************************************************************/
 
-        const ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Sequence< ::com::sun::star::beans::PropertyValue > >& GetAddonsToolBarPart( sal_uInt32 nIndex ) const;
+        const css::uno::Sequence< css::uno::Sequence< css::beans::PropertyValue > >& GetAddonsToolBarPart( sal_uInt32 nIndex ) const;
 
         /*-****************************************************************************************************
             @short      Gets a unique toolbar resource name of an single addon
@@ -192,7 +192,7 @@ class FWE_DLLPUBLIC AddonsOptions
 
             @onerror    We return sal_False
         *//*-*****************************************************************************************************/
-        const ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Sequence< ::com::sun::star::beans::PropertyValue > >& GetAddonsHelpMenu() const;
+        const css::uno::Sequence< css::uno::Sequence< css::beans::PropertyValue > >& GetAddonsHelpMenu() const;
 
         const MergeStatusbarInstructionContainer& GetMergeStatusbarInstructions() const;
 
diff --git a/include/framework/bmkmenu.hxx b/include/framework/bmkmenu.hxx
index 79c8c92..54c4075 100644
--- a/include/framework/bmkmenu.hxx
+++ b/include/framework/bmkmenu.hxx
@@ -44,9 +44,7 @@ class FWE_DLLPUBLIC BmkMenu : public AddonMenu
             BMK_WIZARDMENU
         };
 
-        BmkMenu( ::com::sun::star::uno::Reference< ::com::sun::star::frame::XFrame >& rFrame,
-                 BmkMenuType nType
-        );
+        BmkMenu( css::uno::Reference< css::frame::XFrame >& rFrame, BmkMenuType nType );
 
         virtual ~BmkMenu();
 
diff --git a/include/framework/configimporter.hxx b/include/framework/configimporter.hxx
index 776c944..c35e8d6 100644
--- a/include/framework/configimporter.hxx
+++ b/include/framework/configimporter.hxx
@@ -34,10 +34,10 @@ namespace framework
     {
         public:
             static bool ImportCustomToolbars(
-                        const ::com::sun::star::uno::Reference< ::com::sun::star::ui::XUIConfigurationManager2 >& rContainerFactory,
-                        ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Reference< ::com::sun::star::container::XIndexContainer > >& rSeqContainer,
-                        const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext >& rxContext,
-                        const ::com::sun::star::uno::Reference< ::com::sun::star::embed::XStorage >& rToolbarStorage );
+                        const css::uno::Reference< css::ui::XUIConfigurationManager2 >& rContainerFactory,
+                        css::uno::Sequence< css::uno::Reference< css::container::XIndexContainer > >& rSeqContainer,
+                        const css::uno::Reference< css::uno::XComponentContext >& rxContext,
+                        const css::uno::Reference< css::embed::XStorage >& rToolbarStorage );
     };
 
 } // namespace framework
diff --git a/include/framework/documentundoguard.hxx b/include/framework/documentundoguard.hxx
index ab2f1c9..dc1fb5f 100644
--- a/include/framework/documentundoguard.hxx
+++ b/include/framework/documentundoguard.hxx
@@ -37,13 +37,13 @@ namespace framework
         the XUndoManagerSupplier interface). When entering the scope (i.e. when the <code>DocumentUndoGuard</code>
         instances is constructed), the current state of the undo contexts of the undo manager is examined.
         Upon leaving the scope (i.e. when the <code>DocumentUndoGuard</code> is destructed), the guard will execute
-        as many calls to <member scope="com::sun::star::document">XUndoManager::leaveUndoContext</member> as are
+        as many calls to <member scope="css::document">XUndoManager::leaveUndoContext</member> as are
         necessary to restore the manager's initial state.
     */
     class FWE_DLLPUBLIC DocumentUndoGuard
     {
     public:
-        DocumentUndoGuard( const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& i_undoSupplierComponent );
+        DocumentUndoGuard( const css::uno::Reference< css::uno::XInterface >& i_undoSupplierComponent );
         ~DocumentUndoGuard();
 
     private:
diff --git a/include/framework/eventsconfiguration.hxx b/include/framework/eventsconfiguration.hxx
index 7a4dd3d..45e8b2d 100644
--- a/include/framework/eventsconfiguration.hxx
+++ b/include/framework/eventsconfiguration.hxx
@@ -32,8 +32,8 @@ namespace framework
 
 struct FWE_DLLPUBLIC EventsConfig
 {
-    ::com::sun::star::uno::Sequence< OUString >              aEventNames;
-    ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Any >   aEventsProperties;
+    css::uno::Sequence< OUString >              aEventNames;
+    css::uno::Sequence< css::uno::Any >         aEventsProperties;
 };
 
 } // namespace framework
diff --git a/include/framework/framelistanalyzer.hxx b/include/framework/framelistanalyzer.hxx
index 43d2b28..cdceae2 100644
--- a/include/framework/framelistanalyzer.hxx
+++ b/include/framework/framelistanalyzer.hxx
@@ -61,10 +61,10 @@ class FWE_DLLPUBLIC FrameListAnalyzer
     public:
 
         /** provides access to the frame container, which should be analyzed. */
-        const ::com::sun::star::uno::Reference< ::com::sun::star::frame::XFramesSupplier >& m_xSupplier;
+        const css::uno::Reference< css::frame::XFramesSupplier >& m_xSupplier;
 
         /** hold the reference frame, which is used e.g. to detect other frames with the same model. */
-        const ::com::sun::star::uno::Reference< ::com::sun::star::frame::XFrame >& m_xReferenceFrame;
+        const css::uno::Reference< css::frame::XFrame >& m_xReferenceFrame;
 
         /** enable/disable some special analyzing steps.
             see impl_analyze() for further information. */
@@ -73,19 +73,19 @@ class FWE_DLLPUBLIC FrameListAnalyzer
         /** contains all frames, which uses the same model like the reference frame.
             Will be filled only if m_eDetectMode has set the flag E_MODEL.
             The reference frame is never part of this list! */
-        ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Reference< ::com::sun::star::frame::XFrame > > m_lModelFrames;
+        css::uno::Sequence< css::uno::Reference< css::frame::XFrame > > m_lModelFrames;
 
         /** contains all frames, which does not contain the same model like the reference frame.
             Filling of it can't be suppressed by m_eDetectMode.
             The reference frame is never part of this list!
             All frames inside this list are visible ones. */
-        ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Reference< ::com::sun::star::frame::XFrame > > m_lOtherVisibleFrames;
+        css::uno::Sequence< css::uno::Reference< css::frame::XFrame > > m_lOtherVisibleFrames;
 
         /** contains all frames, which does not contain the same model like the reference frame.
             Filling of it can't be suppressed by m_eDetectMode.
             The reference frame is never part of this list!
             All frames inside this list are hidden ones. */
-        ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Reference< ::com::sun::star::frame::XFrame > > m_lOtherHiddenFrames;
+        css::uno::Sequence< css::uno::Reference< css::frame::XFrame > > m_lOtherHiddenFrames;
 
         /** points to the help frame.
             Will be set only, if any other frame (means different from the reference frame)
@@ -110,7 +110,7 @@ class FWE_DLLPUBLIC FrameListAnalyzer
             Analyzing of the help frame ignores the visible state of any frame.
             But note: a hidden help frame indicates a wrong state!
          */
-        ::com::sun::star::uno::Reference< ::com::sun::star::frame::XFrame > m_xHelp;
+        css::uno::Reference< css::frame::XFrame > m_xHelp;
 
         /** points to the frame, which contains the backing component.
             Will be set only, if any other frame (means different from the reference frame)
@@ -136,7 +136,7 @@ class FWE_DLLPUBLIC FrameListAnalyzer
             Analyzing of the help frame ignores the visible state of any frame.
             But note: a hidden backing mode frame indicates a wrong state!
          */
-        ::com::sun::star::uno::Reference< ::com::sun::star::frame::XFrame > m_xBackingComponent;
+        css::uno::Reference< css::frame::XFrame > m_xBackingComponent;
 
         /** is set to true only, if the reference frame is a hidden one.
             This value is undefined if m_eDetectMode doesn't have set the flag E_HIDDEN! */
@@ -173,8 +173,8 @@ class FWE_DLLPUBLIC FrameListAnalyzer
                     analyze steps. Note: Some member values will be undefined, if
                     an analyze step will be disabled.
          */
-                 FrameListAnalyzer( const ::com::sun::star::uno::Reference< ::com::sun::star::frame::XFramesSupplier >& xSupplier       ,
-                                    const ::com::sun::star::uno::Reference< ::com::sun::star::frame::XFrame >&          xReferenceFrame ,
+                 FrameListAnalyzer( const css::uno::Reference< css::frame::XFramesSupplier >& xSupplier       ,
+                                    const css::uno::Reference< css::frame::XFrame >&          xReferenceFrame ,
                                           sal_uInt32                                          eDetectMode     );
         virtual ~FrameListAnalyzer();
 
diff --git a/include/framework/imageproducer.hxx b/include/framework/imageproducer.hxx
index 876c635..dd16543 100644
--- a/include/framework/imageproducer.hxx
+++ b/include/framework/imageproducer.hxx
@@ -30,7 +30,7 @@ namespace framework
 {
 
 typedef Image ( *pfunc_getImage)(
-    const ::com::sun::star::uno::Reference< ::com::sun::star::frame::XFrame >& rFrame,
+    const css::uno::Reference< css::frame::XFrame >& rFrame,
     const OUString& aURL,
     bool bBig
 );
@@ -38,7 +38,7 @@ typedef Image ( *pfunc_getImage)(
 pfunc_getImage FWE_DLLPUBLIC SAL_CALL SetImageProducer( pfunc_getImage pGetImageFunc );
 
 Image FWE_DLLPUBLIC SAL_CALL GetImageFromURL(
-    const ::com::sun::star::uno::Reference< ::com::sun::star::frame::XFrame >& rFrame,
+    const css::uno::Reference< css::frame::XFrame >& rFrame,
     const OUString& aURL,
     bool bBig
 );
diff --git a/include/framework/interaction.hxx b/include/framework/interaction.hxx
index f3cbe3d..a57b3ed 100644
--- a/include/framework/interaction.hxx
+++ b/include/framework/interaction.hxx
@@ -62,12 +62,12 @@ class FWE_DLLPUBLIC RequestFilterSelect
 {
     RequestFilterSelect_Impl* pImp;
 
-    public:
-        RequestFilterSelect( const OUString& sURL );
-        ~RequestFilterSelect();
-        bool     isAbort  () const;
-        OUString getFilter() const;
-    com::sun::star::uno::Reference < ::com::sun::star::task::XInteractionRequest > GetRequest();
+public:
+    RequestFilterSelect( const OUString& sURL );
+    ~RequestFilterSelect();
+    bool     isAbort  () const;
+    OUString getFilter() const;
+    css::uno::Reference < css::task::XInteractionRequest > GetRequest();
 };
 
 /*-************************************************************************************************************
@@ -84,9 +84,9 @@ class FWE_DLLPUBLIC RequestFilterSelect
 class FWE_DLLPUBLIC InteractionRequest
 {
 public:
-    static com::sun::star::uno::Reference < ::com::sun::star::task::XInteractionRequest >
-        CreateRequest( const ::com::sun::star::uno::Any& aRequest,
-        const ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Reference< ::com::sun::star::task::XInteractionContinuation > >& lContinuations );
+    static css::uno::Reference < css::task::XInteractionRequest > CreateRequest(
+        const css::uno::Any& aRequest,
+        const css::uno::Sequence< css::uno::Reference< css::task::XInteractionContinuation > >& lContinuations );
 };
 
 
diff --git a/include/framework/menuconfiguration.hxx b/include/framework/menuconfiguration.hxx
index c2350e9..25e26f3 100644
--- a/include/framework/menuconfiguration.hxx
+++ b/include/framework/menuconfiguration.hxx
@@ -102,26 +102,27 @@ public:
 
 class FWE_DLLPUBLIC MenuConfiguration
 {
-    public:
+public:
         MenuConfiguration(
             // use const when giving a uno reference by reference
-            const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext >& rxContext );
+            const css::uno::Reference< css::uno::XComponentContext >& rxContext );
 
         virtual ~MenuConfiguration();
 
-        ::com::sun::star::uno::Reference< ::com::sun::star::container::XIndexAccess > CreateMenuBarConfigurationFromXML(
-            ::com::sun::star::uno::Reference< ::com::sun::star::io::XInputStream >& rInputStream )
+        css::uno::Reference< css::container::XIndexAccess > CreateMenuBarConfigurationFromXML(
+            css::uno::Reference< css::io::XInputStream >& rInputStream )
             throw (css::lang::WrappedTargetException, css::uno::RuntimeException);
 
         PopupMenu* CreateBookmarkMenu(css::uno::Reference<css::frame::XFrame >& rFrame, const OUString& aURL)
             throw (css::lang::WrappedTargetException, css::uno::RuntimeException);
 
-        void StoreMenuBarConfigurationToXML( ::com::sun::star::uno::Reference< ::com::sun::star::container::XIndexAccess >& rMenuBarConfiguration,
-                      ::com::sun::star::uno::Reference< ::com::sun::star::io::XOutputStream >& rOutputStream )
+        void StoreMenuBarConfigurationToXML(
+                      css::uno::Reference< css::container::XIndexAccess >& rMenuBarConfiguration,
+                      css::uno::Reference< css::io::XOutputStream >& rOutputStream )
             throw (css::lang::WrappedTargetException, css::uno::RuntimeException);
 
-    private:
-        ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext> m_xContext;
+private:
+        css::uno::Reference< css::uno::XComponentContext> m_xContext;
 };
 
 }
diff --git a/include/framework/preventduplicateinteraction.hxx b/include/framework/preventduplicateinteraction.hxx
index c2137cd..cf6ac00 100644
--- a/include/framework/preventduplicateinteraction.hxx
+++ b/include/framework/preventduplicateinteraction.hxx
@@ -135,8 +135,8 @@ class FWE_DLLPUBLIC PreventDuplicateInteraction : private ThreadHelpBase2
 
             @threadsafe yes
         */
-        virtual sal_Bool SAL_CALL handleInteractionRequest( const ::com::sun::star::uno::Reference< ::com::sun::star::task::XInteractionRequest >& xRequest )
-            throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+        virtual sal_Bool SAL_CALL handleInteractionRequest( const css::uno::Reference< css::task::XInteractionRequest >& xRequest )
+            throw (css::uno::RuntimeException, std::exception) override;
 
 
         /**
@@ -146,8 +146,8 @@ class FWE_DLLPUBLIC PreventDuplicateInteraction : private ThreadHelpBase2
 
             @threadsafe yes
         */
-        virtual ::com::sun::star::uno::Any SAL_CALL queryInterface( const ::com::sun::star::uno::Type& aType )
-            throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+        virtual css::uno::Any SAL_CALL queryInterface( const css::uno::Type& aType )
+            throw (css::uno::RuntimeException, std::exception) override;
 
     // c++ interface
     public:
diff --git a/include/framework/sfxhelperfunctions.hxx b/include/framework/sfxhelperfunctions.hxx
index bad672f..e88e170 100644
--- a/include/framework/sfxhelperfunctions.hxx
+++ b/include/framework/sfxhelperfunctions.hxx
@@ -29,30 +29,30 @@
 #include <svtools/statusbarcontroller.hxx>
 
 typedef svt::ToolboxController* ( *pfunc_setToolBoxControllerCreator)(
-    const ::com::sun::star::uno::Reference< ::com::sun::star::frame::XFrame >& rFrame,
+    const css::uno::Reference< css::frame::XFrame >& rFrame,
     ToolBox* pToolbox,
     unsigned short nID,
     const OUString& aCommandURL );
 
 typedef svt::StatusbarController* ( *pfunc_setStatusBarControllerCreator)(
-    const ::com::sun::star::uno::Reference< ::com::sun::star::frame::XFrame >& rFrame,
+    const css::uno::Reference< css::frame::XFrame >& rFrame,
     StatusBar* pStatusBar,
     unsigned short nID,
     const OUString& aCommandURL );
 
 typedef void ( *pfunc_getRefreshToolbars)(
-    ::com::sun::star::uno::Reference< ::com::sun::star::frame::XFrame >& rFrame );
+    css::uno::Reference< css::frame::XFrame >& rFrame );
 
 typedef void ( *pfunc_createDockingWindow)(
-    const ::com::sun::star::uno::Reference< ::com::sun::star::frame::XFrame >& rFrame,
+    const css::uno::Reference< css::frame::XFrame >& rFrame,
     const OUString& rResourceURL );
 
 typedef bool ( *pfunc_isDockingWindowVisible)(
-    const ::com::sun::star::uno::Reference< ::com::sun::star::frame::XFrame >& rFrame,
+    const css::uno::Reference< css::frame::XFrame >& rFrame,
     const OUString& rResourceURL );
 
 typedef void ( *pfunc_activateToolPanel)(
-    const ::com::sun::star::uno::Reference< ::com::sun::star::frame::XFrame >& i_rFrame,
+    const css::uno::Reference< css::frame::XFrame >& i_rFrame,
     const OUString& i_rPanelURL );
 
 
@@ -60,35 +60,35 @@ namespace framework
 {
 FWE_DLLPUBLIC pfunc_setToolBoxControllerCreator SAL_CALL SetToolBoxControllerCreator( pfunc_setToolBoxControllerCreator pSetToolBoxControllerCreator );
 FWE_DLLPUBLIC svt::ToolboxController* SAL_CALL CreateToolBoxController(
-    const ::com::sun::star::uno::Reference< ::com::sun::star::frame::XFrame >& rFrame,
+    const css::uno::Reference< css::frame::XFrame >& rFrame,
     ToolBox* pToolbox,
     unsigned short nID,
     const OUString& aCommandURL );
 
 FWE_DLLPUBLIC pfunc_setStatusBarControllerCreator SAL_CALL SetStatusBarControllerCreator( pfunc_setStatusBarControllerCreator pSetStatusBarControllerCreator );
 FWE_DLLPUBLIC svt::StatusbarController* SAL_CALL CreateStatusBarController(
-    const ::com::sun::star::uno::Reference< ::com::sun::star::frame::XFrame >& rFrame,
+    const css::uno::Reference< css::frame::XFrame >& rFrame,
     StatusBar* pStatusBar,
     unsigned short nID,
      const OUString& aCommandURL );
 
 FWE_DLLPUBLIC pfunc_getRefreshToolbars SAL_CALL SetRefreshToolbars( pfunc_getRefreshToolbars pRefreshToolbarsFunc );
 FWE_DLLPUBLIC void SAL_CALL RefreshToolbars(
-     ::com::sun::star::uno::Reference< ::com::sun::star::frame::XFrame >& rFrame );
+     css::uno::Reference< css::frame::XFrame >& rFrame );
 
 FWE_DLLPUBLIC pfunc_createDockingWindow SAL_CALL SetDockingWindowCreator( pfunc_createDockingWindow pCreateDockingWindow );
 FWE_DLLPUBLIC void SAL_CALL CreateDockingWindow(
-    const ::com::sun::star::uno::Reference< ::com::sun::star::frame::XFrame >& rFrame,
+    const css::uno::Reference< css::frame::XFrame >& rFrame,
     const OUString& rResourceURL );
 
 FWE_DLLPUBLIC pfunc_isDockingWindowVisible SAL_CALL SetIsDockingWindowVisible( pfunc_isDockingWindowVisible pIsDockingWindowVisible );
 FWE_DLLPUBLIC bool SAL_CALL IsDockingWindowVisible(
-    const ::com::sun::star::uno::Reference< ::com::sun::star::frame::XFrame >& rFrame,
+    const css::uno::Reference< css::frame::XFrame >& rFrame,
     const OUString& rResourceURL );
 
 FWE_DLLPUBLIC pfunc_activateToolPanel SAL_CALL SetActivateToolPanel( pfunc_activateToolPanel i_pActivator );
 FWE_DLLPUBLIC void SAL_CALL ActivateToolPanel(
-    const ::com::sun::star::uno::Reference< ::com::sun::star::frame::XFrame >& i_rFrame,
+    const css::uno::Reference< css::frame::XFrame >& i_rFrame,
     const OUString& i_rPanelURL );
 }
 
diff --git a/include/framework/statusbarconfiguration.hxx b/include/framework/statusbarconfiguration.hxx
index 402f56f..7abcc14 100644
--- a/include/framework/statusbarconfiguration.hxx
+++ b/include/framework/statusbarconfiguration.hxx
@@ -36,14 +36,14 @@ class FWE_DLLPUBLIC StatusBarConfiguration
 {
     public:
         static bool LoadStatusBar(
-            const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext >& xContext,
-            const ::com::sun::star::uno::Reference< ::com::sun::star::io::XInputStream >& xInputStream,
-            const ::com::sun::star::uno::Reference< ::com::sun::star::container::XIndexContainer >& rStatusbarConfiguration );
+            const css::uno::Reference< css::uno::XComponentContext >& xContext,
+            const css::uno::Reference< css::io::XInputStream >& xInputStream,
+            const css::uno::Reference< css::container::XIndexContainer >& rStatusbarConfiguration );
 
         static bool StoreStatusBar(
-            const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext >& xContext,
-            const ::com::sun::star::uno::Reference< ::com::sun::star::io::XOutputStream >& xOutputStream,
-            const ::com::sun::star::uno::Reference< ::com::sun::star::container::XIndexAccess >& rStatusbarConfiguration );
+            const css::uno::Reference< css::uno::XComponentContext >& xContext,
+            const css::uno::Reference< css::io::XOutputStream >& xOutputStream,
+            const css::uno::Reference< css::container::XIndexAccess >& rStatusbarConfiguration );
 };
 
 } // namespace framework
diff --git a/include/framework/toolboxconfiguration.hxx b/include/framework/toolboxconfiguration.hxx
index f19410c..16bc304 100644
--- a/include/framework/toolboxconfiguration.hxx
+++ b/include/framework/toolboxconfiguration.hxx
@@ -35,14 +35,14 @@ class FWE_DLLPUBLIC ToolBoxConfiguration
 {
     public:
         static bool LoadToolBox(
-            const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext >& rxContext,
-            const ::com::sun::star::uno::Reference< ::com::sun::star::io::XInputStream >& rInputStream,
-            const ::com::sun::star::uno::Reference< ::com::sun::star::container::XIndexContainer >& rToolbarConfiguration );
+            const css::uno::Reference< css::uno::XComponentContext >& rxContext,
+            const css::uno::Reference< css::io::XInputStream >& rInputStream,
+            const css::uno::Reference< css::container::XIndexContainer >& rToolbarConfiguration );
 
         static bool StoreToolBox(
-            const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext >& rxContext,
-            const ::com::sun::star::uno::Reference< ::com::sun::star::io::XOutputStream >& rOutputStream,
-            const ::com::sun::star::uno::Reference< ::com::sun::star::container::XIndexAccess >& rToolbarConfiguration );
+            const css::uno::Reference< css::uno::XComponentContext >& rxContext,
+            const css::uno::Reference< css::io::XOutputStream >& rOutputStream,
+            const css::uno::Reference< css::container::XIndexAccess >& rToolbarConfiguration );
 };
 
 } // namespace framework
diff --git a/include/framework/undomanagerhelper.hxx b/include/framework/undomanagerhelper.hxx
index 1b94e3b..6a33919 100644
--- a/include/framework/undomanagerhelper.hxx
+++ b/include/framework/undomanagerhelper.hxx
@@ -66,17 +66,17 @@ namespace framework
     public:
         /** returns the IUndoManager interface to the actual Undo stack
 
-            @throws com::sun::star::lang::DisposedException
+            @throws css::lang::DisposedException
                 when the instance is already disposed, and no IUndoManager can be provided
 
-            @throws com::sun::star::lang::NotInitializedException
+            @throws css::lang::NotInitializedException
                 when the instance is not initialized, yet, and no IUndoManager can be provided
         */
         virtual ::svl::IUndoManager&    getImplUndoManager() = 0;
 
         /** provides access to an UNO interface for the XUndoManager implementation. Used when throwing exceptions.
         */
-        virtual ::com::sun::star::uno::Reference< ::com::sun::star::document::XUndoManager >
+        virtual css::uno::Reference< css::document::XUndoManager >
                                         getThis() = 0;
 
     protected:
@@ -123,22 +123,22 @@ namespace framework
         void            enterUndoContext( const OUString& i_title, IMutexGuard& i_instanceLock );
         void            enterHiddenUndoContext( IMutexGuard& i_instanceLock );
         void            leaveUndoContext( IMutexGuard& i_instanceLock );
-        void            addUndoAction( const ::com::sun::star::uno::Reference< ::com::sun::star::document::XUndoAction >& i_action, IMutexGuard& i_instanceLock );
+        void            addUndoAction( const css::uno::Reference< css::document::XUndoAction >& i_action, IMutexGuard& i_instanceLock );
         void            undo( IMutexGuard& i_instanceLock );
         void            redo( IMutexGuard& i_instanceLock );
         bool            isUndoPossible() const;
         bool            isRedoPossible() const;
         OUString getCurrentUndoActionTitle() const;
         OUString getCurrentRedoActionTitle() const;
-        ::com::sun::star::uno::Sequence< OUString >
+        css::uno::Sequence< OUString >
                         getAllUndoActionTitles() const;
-        ::com::sun::star::uno::Sequence< OUString >
+        css::uno::Sequence< OUString >
                         getAllRedoActionTitles() const;
         void            clear( IMutexGuard& i_instanceLock );
         void            clearRedo( IMutexGuard& i_instanceLock );
         void            reset( IMutexGuard& i_instanceLock );
-        void            addUndoManagerListener( const ::com::sun::star::uno::Reference< ::com::sun::star::document::XUndoManagerListener >& i_listener );
-        void            removeUndoManagerListener( const ::com::sun::star::uno::Reference< ::com::sun::star::document::XUndoManagerListener >& i_listener );
+        void            addUndoManagerListener( const css::uno::Reference< css::document::XUndoManagerListener >& i_listener );
+        void            removeUndoManagerListener( const css::uno::Reference< css::document::XUndoManagerListener >& i_listener );
 
         // XLockable, base of XUndoManager, equivalents
         void            lock();
@@ -146,8 +146,8 @@ namespace framework
         bool            isLocked();
 
         // XModifyBroadcaster equivalents
-        void            addModifyListener( const ::com::sun::star::uno::Reference< ::com::sun::star::util::XModifyListener >& i_listener );
-        void            removeModifyListener( const ::com::sun::star::uno::Reference< ::com::sun::star::util::XModifyListener >& i_listener );
+        void            addModifyListener( const css::uno::Reference< css::util::XModifyListener >& i_listener );
+        void            removeModifyListener( const css::uno::Reference< css::util::XModifyListener >& i_listener );
 
     private:
         std::unique_ptr< UndoManagerHelper_Impl >   m_xImpl;
commit 41b923e76ddea150133fa3a1185e2d337d6d9105
Author: Noel Grandin <noel at peralex.com>
Date:   Tue Oct 20 16:39:20 2015 +0200

    com::sun::star->css in include/formula
    
    Change-Id: Ib217c24614d09817e4d7f8c545bd75345250a874
    Reviewed-on: https://gerrit.libreoffice.org/19493
    Reviewed-by: Noel Grandin <noelgrandin at gmail.com>
    Tested-by: Noel Grandin <noelgrandin at gmail.com>

diff --git a/include/formula/FormulaCompiler.hxx b/include/formula/FormulaCompiler.hxx
index 867d4f1..8e5007e 100644
--- a/include/formula/FormulaCompiler.hxx
+++ b/include/formula/FormulaCompiler.hxx
@@ -167,13 +167,12 @@ public:
         void putExternalSoftly( const OUString & rSymbol, const OUString & rAddIn );
 
         /// Core implementation of XFormulaOpCodeMapper::getMappings()
-        ::com::sun::star::uno::Sequence< ::com::sun::star::sheet::FormulaToken >
+        css::uno::Sequence< css::sheet::FormulaToken >
             createSequenceOfFormulaTokens(const FormulaCompiler& _rCompiler,
-                    const ::com::sun::star::uno::Sequence< OUString >& rNames ) const;
+                    const css::uno::Sequence< OUString >& rNames ) const;
 
         /// Core implementation of XFormulaOpCodeMapper::getAvailableMappings()
-        ::com::sun::star::uno::Sequence<
-            ::com::sun::star::sheet::FormulaOpCodeMapEntry >
+        css::uno::Sequence< css::sheet::FormulaOpCodeMapEntry >
             createSequenceOfAvailableMappings( const FormulaCompiler& _rCompiler,const sal_Int32 nGroup ) const;
 
         /** The value used in createSequenceOfAvailableMappings() and thus in
@@ -195,7 +194,7 @@ public:
 
     /** Get OpCodeMap for formula language.
         @param nLanguage
-            One of ::com::sun::star::sheet::FormulaLanguage constants.
+            One of css::sheet::FormulaLanguage constants.
         @return Map for nLanguage. If nLanguage is unknown, a NULL map is returned.
      */
     OpCodeMapPtr GetOpCodeMap( const sal_Int32 nLanguage ) const;
@@ -205,8 +204,7 @@ public:
             Use English number parser / formatter instead of native.
      */
     static OpCodeMapPtr CreateOpCodeMap(
-            const ::com::sun::star::uno::Sequence<
-            const ::com::sun::star::sheet::FormulaOpCodeMapEntry > & rMapping,
+            const css::uno::Sequence< const css::sheet::FormulaOpCodeMapEntry > & rMapping,
             bool bEnglish );
 
     /** Get current OpCodeMap in effect. */
@@ -278,7 +276,7 @@ protected:
     virtual void fillFromAddInCollectionUpperName( NonConstOpCodeMapPtr xMap ) const;
     virtual void fillFromAddInMap( NonConstOpCodeMapPtr xMap, FormulaGrammar::Grammar _eGrammar ) const;
     virtual void fillFromAddInCollectionEnglishName( NonConstOpCodeMapPtr xMap ) const;
-    virtual void fillAddInToken(::std::vector< ::com::sun::star::sheet::FormulaOpCodeMapEntry >& _rVec,bool _bIsEnglish) const;
+    virtual void fillAddInToken(::std::vector< css::sheet::FormulaOpCodeMapEntry >& _rVec, bool _bIsEnglish) const;
 
     virtual void SetError(sal_uInt16 nError);
     virtual FormulaTokenRef ExtendRangeReference( FormulaToken & rTok1, FormulaToken & rTok2, bool bReuseDoubleRef );
diff --git a/include/formula/FormulaOpCodeMapperObj.hxx b/include/formula/FormulaOpCodeMapperObj.hxx
index f813bf4..1cfc40c 100644
--- a/include/formula/FormulaOpCodeMapperObj.hxx
+++ b/include/formula/FormulaOpCodeMapperObj.hxx
@@ -33,14 +33,14 @@ namespace formula
 {
 
 class FORMULA_DLLPUBLIC FormulaOpCodeMapperObj : public ::cppu::WeakImplHelper2<
-                            ::com::sun::star::sheet::XFormulaOpCodeMapper,
-                            ::com::sun::star::lang::XServiceInfo >
+                            css::sheet::XFormulaOpCodeMapper,
+                            css::lang::XServiceInfo >
 {
     ::std::unique_ptr<FormulaCompiler> m_pCompiler;
 public:
     static OUString  getImplementationName_Static();
-    static ::com::sun::star::uno::Sequence< OUString> getSupportedServiceNames_Static();
-    static ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface > create(const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext >& _xContext);
+    static css::uno::Sequence< OUString> getSupportedServiceNames_Static();
+    static css::uno::Reference< css::uno::XInterface > create(const css::uno::Reference< css::uno::XComponentContext >& _xContext);
 
 protected:
                             FormulaOpCodeMapperObj(::std::unique_ptr<FormulaCompiler> && _pCompiler);
@@ -49,26 +49,26 @@ protected:
 private:
                             // XFormulaOpCodeMapper
                             // Attributes
-    virtual ::sal_Int32 SAL_CALL getOpCodeExternal() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
-    virtual ::sal_Int32 SAL_CALL getOpCodeUnknown() throw (::com::sun::star::uno::RuntimeException, std::exception) override;
+    virtual ::sal_Int32 SAL_CALL getOpCodeExternal() throw (css::uno::RuntimeException, std::exception) override;
+    virtual ::sal_Int32 SAL_CALL getOpCodeUnknown() throw (css::uno::RuntimeException, std::exception) override;
                             // Methods
-    virtual ::com::sun::star::uno::Sequence< ::com::sun::star::sheet::FormulaToken > SAL_CALL getMappings(
-                                    const ::com::sun::star::uno::Sequence< OUString >& rNames,
+    virtual css::uno::Sequence< css::sheet::FormulaToken > SAL_CALL getMappings(
+                                    const css::uno::Sequence< OUString >& rNames,
                                     sal_Int32 nLanguage )
-                                throw ( ::com::sun::star::lang::IllegalArgumentException,
-                                        ::com::sun::star::uno::RuntimeException, std::exception) override;
-    virtual ::com::sun::star::uno::Sequence< ::com::sun::star::sheet::FormulaOpCodeMapEntry > SAL_CALL getAvailableMappings(
+                                throw ( css::lang::IllegalArgumentException,
+                                        css::uno::RuntimeException, std::exception) override;
+    virtual css::uno::Sequence< css::sheet::FormulaOpCodeMapEntry > SAL_CALL getAvailableMappings(
                                     sal_Int32 nLanguage, sal_Int32 nGroups )
-                                throw ( ::com::sun::star::lang::IllegalArgumentException,
-                                        ::com::sun::star::uno::RuntimeException, std::exception) override;
+                                throw ( css::lang::IllegalArgumentException,
+                                        css::uno::RuntimeException, std::exception) override;
 
                             // XServiceInfo
     virtual OUString SAL_CALL getImplementationName()
-                                throw(::com::sun::star::uno::RuntimeException, std::exception) override;
+                                throw(css::uno::RuntimeException, std::exception) override;
     virtual sal_Bool SAL_CALL supportsService( const OUString& ServiceName )
-                                throw(::com::sun::star::uno::RuntimeException, std::exception) override;
-    virtual ::com::sun::star::uno::Sequence< OUString > SAL_CALL getSupportedServiceNames()
-                                throw(::com::sun::star::uno::RuntimeException, std::exception) override;
+                                throw(css::uno::RuntimeException, std::exception) override;
+    virtual css::uno::Sequence< OUString > SAL_CALL getSupportedServiceNames()
+                                throw(css::uno::RuntimeException, std::exception) override;
 
 };
 
diff --git a/include/formula/IFunctionDescription.hxx b/include/formula/IFunctionDescription.hxx
index 78920ba..0d93429f 100644
--- a/include/formula/IFunctionDescription.hxx
+++ b/include/formula/IFunctionDescription.hxx
@@ -132,11 +132,11 @@ namespace formula
         virtual void setReferenceInput(const FormEditData* _pData) = 0;
 
         virtual IFunctionManager*   getFunctionManager() = 0;
-        virtual ::std::unique_ptr<FormulaTokenArray> convertToTokenArray(const ::com::sun::star::uno::Sequence< ::com::sun::star::sheet::FormulaToken >& _aTokenList) = 0;
+        virtual ::std::unique_ptr<FormulaTokenArray> convertToTokenArray(const css::uno::Sequence< css::sheet::FormulaToken >& _aTokenList) = 0;
 
-        virtual ::com::sun::star::uno::Reference< ::com::sun::star::sheet::XFormulaParser> getFormulaParser() const = 0;
-        virtual ::com::sun::star::uno::Reference< ::com::sun::star::sheet::XFormulaOpCodeMapper> getFormulaOpCodeMapper() const = 0;
-        virtual ::com::sun::star::table::CellAddress getReferencePosition() const = 0;
+        virtual css::uno::Reference< css::sheet::XFormulaParser> getFormulaParser() const = 0;
+        virtual css::uno::Reference< css::sheet::XFormulaOpCodeMapper> getFormulaOpCodeMapper() const = 0;
+        virtual css::table::CellAddress getReferencePosition() const = 0;
 
         virtual void setDispatcherLock( bool bLock ) = 0;
         virtual void dispatch(bool _bOK, bool _bMatrixChecked) = 0;
diff --git a/include/formula/grammar.hxx b/include/formula/grammar.hxx
index 618db98..91ca7ae11 100644
--- a/include/formula/grammar.hxx
+++ b/include/formula/grammar.hxx
@@ -68,77 +68,77 @@ public:
         /// Used only in ScCompiler ctor and in some XML import API context.
         GRAM_UNSPECIFIED    = -1,
         /// ODFF with default ODF A1 bracketed references.
-        GRAM_ODFF           = ::com::sun::star::sheet::FormulaLanguage::ODFF    |
+        GRAM_ODFF           = css::sheet::FormulaLanguage::ODFF                 |
                                 ((CONV_ODF           +
                                   kConventionOffset) << kConventionShift)       |
                                 kEnglishBit,
         /// ODF 1.1 with default ODF A1 bracketed references.
-        GRAM_PODF           = ::com::sun::star::sheet::FormulaLanguage::ODF_11  |
+        GRAM_PODF           = css::sheet::FormulaLanguage::ODF_11               |
                                 ((CONV_ODF           +
                                   kConventionOffset) << kConventionShift)       |
                                 kEnglishBit,
         /// English with default A1 reference style.
-        GRAM_ENGLISH        = ::com::sun::star::sheet::FormulaLanguage::ENGLISH |
+        GRAM_ENGLISH        = css::sheet::FormulaLanguage::ENGLISH              |
                                 ((CONV_OOO           +
                                   kConventionOffset) << kConventionShift)       |
                                 kEnglishBit,
         /// Native with default A1 reference style.
-        GRAM_NATIVE         = ::com::sun::star::sheet::FormulaLanguage::NATIVE  |
+        GRAM_NATIVE         = css::sheet::FormulaLanguage::NATIVE               |
                                 ((CONV_OOO           +
                                   kConventionOffset) << kConventionShift),
         /// ODFF with reference style as set in UI, may be A1 or R1C1.
-        GRAM_ODFF_UI        = ::com::sun::star::sheet::FormulaLanguage::ODFF    |
+        GRAM_ODFF_UI        = css::sheet::FormulaLanguage::ODFF                 |
                                 ((CONV_UNSPECIFIED   +
                                   kConventionOffset) << kConventionShift)       |
                                 kEnglishBit,
         /// ODFF with A1 reference style, unbracketed.
-        GRAM_ODFF_A1        = ::com::sun::star::sheet::FormulaLanguage::ODFF    |
+        GRAM_ODFF_A1        = css::sheet::FormulaLanguage::ODFF                 |
                                 ((CONV_OOO           +
                                   kConventionOffset) << kConventionShift)       |
                                 kEnglishBit,
         /// ODF 1.1 with reference style as set in UI, may be A1 or R1C1.
-        GRAM_PODF_UI        = ::com::sun::star::sheet::FormulaLanguage::ODF_11  |
+        GRAM_PODF_UI        = css::sheet::FormulaLanguage::ODF_11               |
                                 ((CONV_UNSPECIFIED   +
                                   kConventionOffset) << kConventionShift)       |
                                 kEnglishBit,
         /// ODF 1.1 with A1 reference style, unbracketed.
-        GRAM_PODF_A1        = ::com::sun::star::sheet::FormulaLanguage::ODF_11  |
+        GRAM_PODF_A1        = css::sheet::FormulaLanguage::ODF_11               |
                                 ((CONV_OOO           +
                                   kConventionOffset) << kConventionShift)       |
                                 kEnglishBit,
         /// Native with reference style as set in UI, may be A1 or R1C1.
-        GRAM_NATIVE_UI      = ::com::sun::star::sheet::FormulaLanguage::NATIVE  |
+        GRAM_NATIVE_UI      = css::sheet::FormulaLanguage::NATIVE               |
                                 ((CONV_UNSPECIFIED   +
                                   kConventionOffset) << kConventionShift),
         /// Native with ODF A1 bracketed references. Not very useful but supported.
-        GRAM_NATIVE_ODF     = ::com::sun::star::sheet::FormulaLanguage::NATIVE  |
+        GRAM_NATIVE_ODF     = css::sheet::FormulaLanguage::NATIVE               |
                                 ((CONV_ODF           +
                                   kConventionOffset) << kConventionShift),
         /// Native with Excel A1 reference style.
-        GRAM_NATIVE_XL_A1   = ::com::sun::star::sheet::FormulaLanguage::NATIVE  |
+        GRAM_NATIVE_XL_A1   = css::sheet::FormulaLanguage::NATIVE               |
                                 ((CONV_XL_A1         +
                                   kConventionOffset) << kConventionShift),
         /// Native with Excel R1C1 reference style.
-        GRAM_NATIVE_XL_R1C1 = ::com::sun::star::sheet::FormulaLanguage::NATIVE  |
+        GRAM_NATIVE_XL_R1C1 = css::sheet::FormulaLanguage::NATIVE               |
                                 ((CONV_XL_R1C1       +
                                   kConventionOffset) << kConventionShift),
         /// English with Excel A1 reference style.
-        GRAM_ENGLISH_XL_A1   = ::com::sun::star::sheet::FormulaLanguage::XL_ENGLISH  |
+        GRAM_ENGLISH_XL_A1   = css::sheet::FormulaLanguage::XL_ENGLISH               |
                                 ((CONV_XL_A1         +
                                   kConventionOffset) << kConventionShift)            |
                                 kEnglishBit,
         /// English with Excel R1C1 reference style.
-        GRAM_ENGLISH_XL_R1C1 = ::com::sun::star::sheet::FormulaLanguage::XL_ENGLISH  |
+        GRAM_ENGLISH_XL_R1C1 = css::sheet::FormulaLanguage::XL_ENGLISH               |
                                 ((CONV_XL_R1C1       +
                                   kConventionOffset) << kConventionShift)            |
                                 kEnglishBit,
         /// English with Excel OOXML reference style.
-        GRAM_ENGLISH_XL_OOX  = ::com::sun::star::sheet::FormulaLanguage::XL_ENGLISH  |
+        GRAM_ENGLISH_XL_OOX  = css::sheet::FormulaLanguage::XL_ENGLISH               |
                                 ((CONV_XL_OOX        +
                                   kConventionOffset) << kConventionShift)            |
                                 kEnglishBit,
         /// Excel OOXML with Excel OOXML reference style.
-        GRAM_OOXML           = ::com::sun::star::sheet::FormulaLanguage::OOXML  |
+        GRAM_OOXML           = css::sheet::FormulaLanguage::OOXML               |
                                 ((CONV_XL_OOX        +
                                   kConventionOffset) << kConventionShift)       |
                                 kEnglishBit,
@@ -186,21 +186,21 @@ public:
     static inline bool isPODF( const Grammar eGrammar )
     {
         return extractFormulaLanguage( eGrammar) ==
-            ::com::sun::star::sheet::FormulaLanguage::ODF_11;
+            css::sheet::FormulaLanguage::ODF_11;
     }
 
     /// If grammar is of ODFF
     static inline bool isODFF( const Grammar eGrammar )
     {
         return extractFormulaLanguage( eGrammar) ==
-            ::com::sun::star::sheet::FormulaLanguage::ODFF;
+            css::sheet::FormulaLanguage::ODFF;
     }
 
     /// If grammar is of OOXML
     static inline bool isOOXML( const Grammar eGrammar )
     {
         return extractFormulaLanguage( eGrammar) ==
-            ::com::sun::star::sheet::FormulaLanguage::OOXML;
+            css::sheet::FormulaLanguage::OOXML;
     }
 
 };


More information about the Libreoffice-commits mailing list
diff --git a/include/framework/actiontriggerhelper.hxx b/include/framework/actiontriggerhelper.hxx
index fd7f7a6..392e5dc 100644
--- a/include/framework/actiontriggerhelper.hxx
+++ b/include/framework/actiontriggerhelper.hxx
@@ -37,9 +37,9 @@ namespace framework
             static void
                 CreateMenuFromActionTriggerContainer(
                     Menu* pNewMenu,
-                    const com::sun::star::uno::Reference< com::sun::star::container::XIndexContainer >& rActionTriggerContainer );
+                    const css::uno::Reference< css::container::XIndexContainer >& rActionTriggerContainer );
 
             // Creates a "com::sun::star::ui::ActionTriggerContainer" with the structure of the menu
             // provided as a parameter. The implementation class stores the menu pointer
             // to optimize the time of creation of a menu from a actiontrigger structure.
             // IMPORTANT: The caller must ensure that the menu pointer is valid through the
@@ -47,7 +47,7 @@ namespace framework
             // @param pNewMenu = Must be a valid menu. Please be aware that this implementation is based on
             //                   the above mentioned restriction!!!
 
-            static com::sun::star::uno::Reference< com::sun::star::container::XIndexContainer > CreateActionTriggerContainerFromMenu(
+            static css::uno::Reference< css::container::XIndexContainer > CreateActionTriggerContainerFromMenu(
                 const Menu* pMenu, const OUString* pMenuIdentifier );
 
             // Fills the submitted rActionTriggerContainer with the structure of the menu
@@ -56,7 +56,7 @@ namespace framework
             // @param pNewMenu = must be a valid menu
             static void
                 FillActionTriggerContainerFromMenu(
-                    com::sun::star::uno::Reference< com::sun::star::container::XIndexContainer >& rActionTriggerContainer,
+                    css::uno::Reference< css::container::XIndexContainer >& rActionTriggerContainer,
                     const Menu* pMenu );
 
     };
@@ -37,9 +37,9 @@ namespace framework
 
-            // Creates a "com::sun::star::ui::ActionTriggerContainer" with the structure of the menu
+            // Creates a "css::ui::ActionTriggerContainer" with the structure of the menu
             // provided as a parameter. The implementation class stores the menu pointer
             // to optimize the time of creation of a menu from a actiontrigger structure.